@@ -2,11 +2,13 @@ import pandas as pd
 import numpy as np
 import matplotlib.pyplot as plt
 import seaborn as sns
+from pandas.api.extensions import register_series_accessor, register_dataframe_accessor
 
 
-@pd.api.extensions.register_series_accessor("log_returns")
-class Returns:
-    """Given a Prices Series, will build the logarithmic returns and
+@register_series_accessor("log_returns")
+@register_dataframe_accessor("log_returns")
+class LogReturns:
+    """Given a pandas object, will build the logarithmic returns and
     attach several properties
     """
 
@@ -22,9 +24,18 @@ class Returns:
     def data(self):
         return self._obj
 
+    def __call__(self):
+        return self._obj
+
+    def __getitem__(self, idx):
+        return self._obj.loc[idx]
+
     @property
-    def srri(self):
-        return self._obj.srri
+    def total(self):
+        """Returss the total return on an investment.
+        It is the aggregate amount that the investment has gained
+        or lost over time, independent of the amount of time involved."""
+        return np.expm1(self._obj.sum())
 
     def plot(self):  # pragma: no cover
         gridkw = dict(height_ratios=[5, 1])
