@@ -1,10 +1,11 @@
 import numpy as np
+import pandas as pd
 
 
 class BetaCovariance:
     """
     Given a Returns Series calculates the beta of a Stock over
-    the Benchmark index using using covariance
+    the Benchmark index using covariance
     """
 
     def __init__(self, independent_variable, dependent_variable):
@@ -14,10 +15,15 @@ class BetaCovariance:
         independent_variable : Market Returns
         dependent_variable : Stock Returns
         """
-
+        self._validate(independent_variable, dependent_variable)
         self.independent_variable = independent_variable.dropna()
         self.dependent_variable = dependent_variable.dropna()
 
+    @staticmethod
+    def _validate(independent_variable, dependent_variable):
+        assert isinstance(independent_variable.index, pd.DatetimeIndex)
+        assert isinstance(dependent_variable.index, pd.DatetimeIndex)
+
     @property
     def beta(self):
         """
