@@ -1,4 +1,5 @@
 import numpy as np
+import pandas as pd
 from sklearn.linear_model import LinearRegression
 
 
@@ -15,10 +16,15 @@ class BetaRegression:
         independent_variable : Market Returns
         dependent_variable : Stock Returns
         """
-
+        self._validate(independent_variable, dependent_variable)
         self.independent_variable = independent_variable.dropna()
         self.dependent_variable = dependent_variable.dropna()
 
+    @staticmethod
+    def _validate(independent_variable, dependent_variable):
+        assert isinstance(independent_variable.index, pd.DatetimeIndex)
+        assert isinstance(dependent_variable.index, pd.DatetimeIndex)
+
     @property
     def beta(self):
         """
